@@ -1,39 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Assistant of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -49,9 +36,7 @@
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
 #include <QtCore/QFileSystemWatcher>
-#include <QtCore/QThread>
 #include <QtCore/QTextStream>
-#include <QtCore/QSocketNotifier>
 
 #include <QtWidgets/QMessageBox>
 #include <QtWidgets/QApplication>
@@ -61,58 +46,13 @@
 #include <QtHelp/QHelpSearchQueryWidget>
 
 #ifdef Q_OS_WIN
-#   include "remotecontrol_win.h"
+#   include "stdinlistener_win.h"
+#else
+#   include "stdinlistener.h"
 #endif
 
 QT_BEGIN_NAMESPACE
 
-#ifdef Q_OS_WIN
-
-StdInListenerWin::StdInListenerWin(QObject *parent)
-    : QThread(parent)
-{
-    TRACE_OBJ
-}
-
-StdInListenerWin::~StdInListenerWin()
-{
-    TRACE_OBJ
-    terminate();
-    wait();
-}
-
-void StdInListenerWin::run()
-{
-    TRACE_OBJ
-    bool ok = true;
-    char chBuf[4096];
-    DWORD dwRead;
-
-#ifndef Q_OS_WINCE
-    HANDLE hStdin, hStdinDup;
-
-    hStdin = GetStdHandle(STD_INPUT_HANDLE);
-    if (hStdin == INVALID_HANDLE_VALUE)
-        return;
-
-    DuplicateHandle(GetCurrentProcess(), hStdin,
-        GetCurrentProcess(), &hStdinDup,
-        0, false, DUPLICATE_SAME_ACCESS);
-
-    CloseHandle(hStdin);
-#else
-    HANDLE hStdinDup;
-    hStdinDup = stdin;
-#endif
-
-    while (ok) {
-        ok = ReadFile(hStdinDup, chBuf, sizeof(chBuf), &dwRead, NULL);
-        if (ok && dwRead != 0)
-            emit receivedCommand(QString::fromLocal8Bit(chBuf, dwRead));
-    }
-}
-#endif
-
 RemoteControl::RemoteControl(MainWindow *mainWindow)
     : QObject(mainWindow)
     , m_mainWindow(mainWindow)
@@ -125,33 +65,11 @@ RemoteControl::RemoteControl(MainWindow *mainWindow)
 {
     TRACE_OBJ
     connect(m_mainWindow, SIGNAL(initDone()), this, SLOT(applyCache()));
-#ifdef Q_OS_WIN
-    StdInListenerWin *l = new StdInListenerWin(this);
+
+    StdInListener *l = new StdInListener(this);
     connect(l, SIGNAL(receivedCommand(QString)),
         this, SLOT(handleCommandString(QString)));
     l->start();
-#else
-    QSocketNotifier *notifier = new QSocketNotifier(fileno(stdin),
-        QSocketNotifier::Read, this);
-    connect(notifier, SIGNAL(activated(int)), this, SLOT(receivedData()));
-    notifier->setEnabled(true);
-#endif
-}
-
-void RemoteControl::receivedData()
-{
-    TRACE_OBJ
-    QByteArray ba;
-    while (true) {
-        const int c = getc(stdin);
-        if (c == EOF || c == '\0')
-            break;
-        if (c)
-            ba.append(char(c));
-         if (c == '\n')
-             break;
-    }
-    handleCommandString(QString::fromLocal8Bit(ba));
 }
 
 void RemoteControl::handleCommandString(const QString &cmdString)
