@@ -145,8 +145,6 @@ public:
 
     QToolBar *toolBarByName(const QString &toolBarName) const;
 
-    QtFullToolBarManagerPrivate();
-
     QMap<QString, QList<QAction *> > categoryToActions;
     QMap<QAction *, QString>         actionToCategory;
 
@@ -160,17 +158,9 @@ public:
     QMap<QToolBar *, QList<QAction *> > defaultToolBars;
     QList<QToolBar *> customToolBars;
 
-    QMainWindow *theMainWindow;
+    QMainWindow *theMainWindow{nullptr};
 };
 
-
-
-
-QtFullToolBarManagerPrivate::QtFullToolBarManagerPrivate()
-    : theMainWindow(0)
-{
-}
-
 QToolBar *QtFullToolBarManagerPrivate::toolBarWidgetAction(QAction *action) const
 {
     if (widgetActions.contains(action))
@@ -761,7 +751,7 @@ QByteArray QtFullToolBarManager::saveState(int version) const
 {
     QByteArray data;
     QDataStream stream(&data, QIODevice::WriteOnly);
-    stream << QtFullToolBarManagerPrivate::VersionMarker;
+    stream << int(QtFullToolBarManagerPrivate::VersionMarker);
     stream << version;
     d_ptr->saveState(stream);
     return data;
